==> kvlibsdk_5_27_776.tar.gz: kvlibsdk/doc/HTMLhelp/navtreedata.js <==
var NAVTREE =
[
  [ "Welcome to Kvaser Linux Drivers and SDK!", "index.html", [
    [ "Installation", "page_installing.html", [
      [ "Installing on Windows", "page_installing.html#section_install_windows", [
        [ "Installing the Driver", "page_installing.html#section_install_driver_windows", null ],
        [ "Removing the driver", "page_installing.html#section_uninstall_driver_windows", null ],
        [ "Installing Kvaser CANlib SDK", "page_installing.html#section_install_sdk_windows", null ],
        [ "Removing Kvaser CANlib SDK", "page_installing.html#section_uninstall_sdk_windows", null ]
      ] ],
      [ "Installing on Linux", "page_installing.html#section_install_linux", [
        [ "Installing the Driver", "page_installing.html#section_install_driver_linux", null ],
        [ "Removing the driver", "page_installing.html#section_uninstall_driver_linux", null ],
        [ "Installing Kvaser CANlib SDK", "page_installing.html#section_install_sdk_linux", null ],
        [ "Removing Kvaser CANlib SDK", "page_installing.html#section_uninstall_sdk_linux", null ]
      ] ],
      [ "Hardware Installation", "page_installing.html#section_install_hardware", null ]
    ] ],
    [ "Tutorials", "page_tutorial.html", "page_tutorial" ],
    [ "CAN bus API (CANlib)", "page_canlib.html", "page_canlib" ],
    [ "LIN bus API (LINlib)", "page_linlib.html", [
      [ "Description", "page_linlib.html#section_user_guide_lin_lib_1", null ],
      [ "Using the LIN Bus", "page_linlib.html#section_user_guide_lin_intro", null ],
      [ "LIN Frame Identifiers", "page_linlib.html#section_user_guide_lin_frame_identifiers", null ],
      [ "Where to go from here", "page_linlib.html#section_user_guide_lin_where_to_go_from_here", null ]
    ] ],
    [ "Database API (kvaDbLib)", "page_kvadblib.html", "page_kvadblib" ],
    [ "Converter API (kvlclib)", "page_kvlclib.html", [
      [ "Description", "page_kvlclib.html#section_user_guide_kvlclib_1", null ],
      [ "Naming convention", "page_kvlclib.html#section_user_guide_kvlclib_2", null ],
      [ "Build an application", "page_kvlclib.html#section_user_guide_kvlclib_3", null ]
    ] ],
    [ "Memorator API (kvmlib)", "page_kvmlib.html", [
      [ "Description", "page_kvmlib.html#section_user_guide_kvmlib_1", null ],
      [ "Naming convention", "page_kvmlib.html#section_user_guide_kvmlib_2", null ],
      [ "Build an application", "page_kvmlib.html#section_user_guide_kvmlib_3", null ]
    ] ],
    [ "Memorator XML API (kvaMemoLibXML)", "page_kvamemolibxml.html", [
      [ "Description", "page_kvamemolibxml.html#section_user_guide_kvamemolibxml_1", null ],
      [ "Build an application", "page_kvamemolibxml.html#section_user_guide_kvamemolibxml_2", null ]
    ] ],
    [ "Remote Device API (kvrlib)", "page_kvrlib.html", [
      [ "Description", "page_kvrlib.html#section_user_guide_kvrlib_1", null ]
    ] ],
    [ "License and Copyright", "page_license_and_copyright.html", null ],
    [ "Sample Programs (kvrlib)", "page_user_guide_kvrlib_samples.html", "page_user_guide_kvrlib_samples" ],
    [ "Kvaser Support", "page_support.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"canlib_8h.html#ac32450667b5263b0068490294e9870bb",
"group___c_a_n.html#ga7eb8c2e92cfae57e7ec5031818524301",
"group__kvadb__attributes.html#ga8dc2f474a745af37d128a7cca676fa4d",
"group__kvaxml__initialization.html#ga0b3e78afddf41c2c096af41fbcea1ba7",
"group__lin__status__codes.html#gga7a5ecfd2846ddd76cd49fb4edec7fc14a9dba946875481393e81a7498ab15bd44",
"kvlclib_8h.html#af46e219b377f67d038aab3d54034846a",
"page_user_guide_send_recv_asynch_not.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> kvlibsdk_5_28_846.tar.gz: kvlibsdk/doc/HTMLhelp/navtreedata.js <==
var NAVTREE =
[
  [ "Welcome to Kvaser Linux Drivers and SDK!", "index.html", [
    [ "Installation", "page_installing.html", [
      [ "Installing on Windows", "page_installing.html#section_install_windows", [
        [ "Installing the Driver", "page_installing.html#section_install_driver_windows", null ],
        [ "Removing the driver", "page_installing.html#section_uninstall_driver_windows", null ],
        [ "Installing Kvaser CANlib SDK", "page_installing.html#section_install_sdk_windows", null ],
        [ "Removing Kvaser CANlib SDK", "page_installing.html#section_uninstall_sdk_windows", null ]
      ] ],
      [ "Installing on Linux", "page_installing.html#section_install_linux", [
        [ "Installing the Driver", "page_installing.html#section_install_driver_linux", null ],
        [ "Removing the driver", "page_installing.html#section_uninstall_driver_linux", null ],
        [ "Installing Kvaser CANlib SDK", "page_installing.html#section_install_sdk_linux", null ],
        [ "Removing Kvaser CANlib SDK", "page_installing.html#section_uninstall_sdk_linux", null ]
      ] ],
      [ "Hardware Installation", "page_installing.html#section_install_hardware", null ]
    ] ],
    [ "Tutorials", "page_tutorial.html", "page_tutorial" ],
    [ "CAN bus API (CANlib)", "page_canlib.html", "page_canlib" ],
    [ "LIN bus API (LINlib)", "page_linlib.html", [
      [ "Description", "page_linlib.html#section_user_guide_lin_lib_1", null ],
      [ "Using the LIN Bus", "page_linlib.html#section_user_guide_lin_intro", null ],
      [ "LIN Frame Identifiers", "page_linlib.html#section_user_guide_lin_frame_identifiers", null ],
      [ "Where to go from here", "page_linlib.html#section_user_guide_lin_where_to_go_from_here", null ]
    ] ],
    [ "Database API (kvaDbLib)", "page_kvadblib.html", "page_kvadblib" ],
    [ "Converter API (kvlclib)", "page_kvlclib.html", [
      [ "Description", "page_kvlclib.html#section_user_guide_kvlclib_1", null ],
      [ "Naming convention", "page_kvlclib.html#section_user_guide_kvlclib_2", null ],
      [ "Build an application", "page_kvlclib.html#section_user_guide_kvlclib_3", null ]
    ] ],
    [ "Memorator API (kvmlib)", "page_kvmlib.html", [
      [ "Description", "page_kvmlib.html#section_user_guide_kvmlib_1", null ],
      [ "Naming convention", "page_kvmlib.html#section_user_guide_kvmlib_2", null ],
      [ "Build an application", "page_kvmlib.html#section_user_guide_kvmlib_3", null ]
    ] ],
    [ "Memorator XML API (kvaMemoLibXML)", "page_kvamemolibxml.html", [
      [ "Description", "page_kvamemolibxml.html#section_user_guide_kvamemolibxml_1", null ],
      [ "Build an application", "page_kvamemolibxml.html#section_user_guide_kvamemolibxml_2", null ]
    ] ],
    [ "Remote Device API (kvrlib)", "page_kvrlib.html", [
      [ "Description", "page_kvrlib.html#section_user_guide_kvrlib_1", null ]
    ] ],
    [ "License and Copyright", "page_license_and_copyright.html", null ],
    [ "Sample Programs (kvrlib)", "page_user_guide_kvrlib_samples.html", "page_user_guide_kvrlib_samples" ],
    [ "Kvaser Support", "page_support.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"canlib_8h.html#ac32450667b5263b0068490294e9870bb",
"group___c_a_n.html#ga7eb8c2e92cfae57e7ec5031818524301",
"group__kvadb__attributes.html#ga8dc2f474a745af37d128a7cca676fa4d",
"group__kvaxml__conversion.html#gafe1b337165ebfa64edf379be0880ef26",
"group__lin__status__codes.html#gga7a5ecfd2846ddd76cd49fb4edec7fc14a9711c64975b2dffdbac707f8b5985192",
"kvlclib_8h.html#adafa7417153216d22ae5460a0e17e6d6",
"page_user_guide_send_recv.html#section_user_guide_misc_code_and_mask"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
